import React, { createContext, useState, useContext } from 'react';

const ErrorContext = createContext<{
  error: string | null;
  showError: (message: string) => void;
  hideError: () => void;
}>({
  error: null,
  showError: (message: string) => {},
  hideError: () => {}
});

export const ErrorProvider = ({ children }: { children: React.ReactNode }) => {
  const [error, setError] = useState<string | null>(null);

  const showError = (message: string) => {
    setError(message);
  };

  const hideError = () => {
    setError(null);
  };

  return (
    <ErrorContext.Provider value={{ error, showError, hideError }}>
      {children}
    </ErrorContext.Provider>
  );
};

export const useError = () => useContext(ErrorContext);
